==> sdl-0.9.0.tgz: sdl-0.9.0/php_sdl_time.c <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2013 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Santiago Lizardo <santiagolizardo@php.net>                   |
  +----------------------------------------------------------------------+
*/

#include "php.h"
#include "php_sdl.h"

#include "ext/standard/basic_functions.h"

#include <SDL.h>

/* {{{ proto int sdl_getticks(void)

 */
// Uint32 SDL_GetTicks(void);
PHP_FUNCTION(sdl_getticks)
{
	if (zend_parse_parameters_none() == FAILURE)
		return;

	RETURN_LONG( SDL_GetTicks() );
}
/* }}} */

/* {{{ proto int sdl_delay(int ms)

 */
// void SDL_Delay(Uint32 ms);
PHP_FUNCTION(sdl_delay)
{
	long ms;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &ms) == FAILURE) {
		WRONG_PARAM_COUNT;
	}

	SDL_Delay( (Uint32)ms );
}
/* }}} */
/*
static Uint32 php_sdl_timer_callback(Uint32 interval, void *param)
{
	// FIXME: doesn't work yet
	php_sdl_timer_t *php_timer = (php_sdl_timer_t *)param;
	void ***tsrm_ls = (void ***) ts_resource_ex(0, &(php_timer->caller_thread_id));
	zval *retval;

	MAKE_STD_ZVAL(retval);
	if (call_user_function(EG(function_table), NULL, php_timer->callback, retval, php_timer->num_callback_args, php_timer->callback_args, tsrm_ls) == FAILURE) {
		php_error(E_WARNING, "%s() calling user callback failed",
				  get_active_function_name(TSRMLS_C));
	} else {
		convert_to_long(retval);
		interval = Z_LVAL_P(retval);
	}
	zval_ptr_dtor(&retval);

	return interval;
}
*/
/* {{{ proto resource sdl_addtimer(int interval, string callback, array param)

 */
// SDL_TimerID SDL_AddTimer(Uint32 interval, SDL_NewTimerCallback callback, void *param);

PHP_FUNCTION(sdl_addtimer)
{ /*
	// FIXME: doesn't work yet
	char *callback_name;
	php_sdl_timer_t *php_timer;
	zval ***args = NULL;

	if (ZEND_NUM_ARGS() < 2) {
		WRONG_PARAM_COUNT;
	}
	
	args = (zval ***)emalloc(ZEND_NUM_ARGS() * sizeof(zval **));
	if (zend_get_parameters_array_ex(ZEND_NUM_ARGS(), args) == FAILURE) {
		php_error(E_WARNING, "%s() unable to obtain function arguments",
				  get_active_function_name(TSRMLS_C));
		efree(args);
		RETURN_FALSE;
	}

	// First argument is the interval
	convert_to_long_ex(args[0]);

	// Second argument has to be a valid callback
	if (!zend_is_callable(*args[1], 0, &callback_name)) {
		php_error(E_WARNING, "%s() requires argument 2, '%s', to be a valid callback",
				  get_active_function_name(TSRMLS_C), callback_name);
		efree(callback_name);
		efree(args);
		RETURN_FALSE;
	}
	efree(callback_name);

 	php_timer = ecalloc(1, sizeof(php_sdl_timer_t));
	// We need the callers thread id for the callback to occur in the right thread
	php_timer->caller_thread_id = tsrm_thread_id();
	php_timer->callback_args = NULL;
	php_timer->num_callback_args = 0;

	// All parameters passed after the callback zval* are passed to the
	// callback itself.

	if ((php_timer->num_callback_args = ZEND_NUM_ARGS() - 2) > 0) {
		int i;
		if (NULL == (php_timer->callback_args = (zval **)emalloc(php_timer->num_callback_args * sizeof(zval *)))) {
			efree(php_timer);
			efree(args);
			RETURN_FALSE;
		}
		for (i = 0; i < php_timer->num_callback_args; i++) {
			zval_add_ref(args[2 + i]);
			php_timer->callback_args[0] = *args[2 + i];
		}
	}

	zval_add_ref(args[1]);
	php_timer->callback = *args[1];

	//php_timer->timerid = SDL_AddTimer((Uint32)Z_LVAL_PP(args[0]), php_sdl_timer_callback, (void*)php_timer);

	ZEND_REGISTER_RESOURCE(return_value, php_timer, le_timer);
	efree(args);
*/
}

/* }}} */

/* {{{ proto bool sdl_removetimer(resource id)

 */
// SDL_bool SDL_RemoveTimer(SDL_TimerID id);

PHP_FUNCTION(sdl_removetimer)
{/*
	// FIXME: doesn't work yet
	zval *timer_arg;
	php_sdl_timer_t *php_timer;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "r", &timer_arg) == FAILURE)
		return;

	ZEND_FETCH_RESOURCE(php_timer, php_sdl_timer_t *, &timer_arg, -1, le_timer_name, le_timer);
	zend_list_delete(Z_RESVAL_P(timer_arg));
*/
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */

==> sdl-0.9.1.tgz: sdl-0.9.1/php_sdl_time.c <==
/*
  +----------------------------------------------------------------------+
  | PHP Version 5                                                        |
  +----------------------------------------------------------------------+
  | Copyright (c) 1997-2013 The PHP Group                                |
  +----------------------------------------------------------------------+
  | This source file is subject to version 3.01 of the PHP license,      |
  | that is bundled with this package in the file LICENSE, and is        |
  | available through the world-wide-web at the following url:           |
  | http://www.php.net/license/3_01.txt                                  |
  | If you did not receive a copy of the PHP license and are unable to   |
  | obtain it through the world-wide-web, please send a note to          |
  | license@php.net so we can mail you a copy immediately.               |
  +----------------------------------------------------------------------+
  | Author: Santiago Lizardo <santiagolizardo@php.net>                   |
  +----------------------------------------------------------------------+
*/

#include "php_sdl_time.h"

#include "ext/standard/basic_functions.h"

#include <SDL.h>

/* {{{ proto int sdl_getticks(void)

 */
// Uint32 SDL_GetTicks(void);
PHP_FUNCTION(sdl_getticks)
{
	if (zend_parse_parameters_none() == FAILURE)
		return;

	RETURN_LONG( SDL_GetTicks() );
}
/* }}} */

/* {{{ proto int sdl_delay(int ms)

 */
// void SDL_Delay(Uint32 ms);
PHP_FUNCTION(sdl_delay)
{
	long ms;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "l", &ms) == FAILURE) {
		WRONG_PARAM_COUNT;
	}

	SDL_Delay( (Uint32)ms );
}
/* }}} */
/*
static Uint32 php_sdl_timer_callback(Uint32 interval, void *param)
{
	// FIXME: doesn't work yet
	php_sdl_timer_t *php_timer = (php_sdl_timer_t *)param;
	void ***tsrm_ls = (void ***) ts_resource_ex(0, &(php_timer->caller_thread_id));
	zval *retval;

	MAKE_STD_ZVAL(retval);
	if (call_user_function(EG(function_table), NULL, php_timer->callback, retval, php_timer->num_callback_args, php_timer->callback_args, tsrm_ls) == FAILURE) {
		php_error(E_WARNING, "%s() calling user callback failed",
				  get_active_function_name(TSRMLS_C));
	} else {
		convert_to_long(retval);
		interval = Z_LVAL_P(retval);
	}
	zval_ptr_dtor(&retval);

	return interval;
}
*/
/* {{{ proto resource sdl_addtimer(int interval, string callback, array param)

 */
// SDL_TimerID SDL_AddTimer(Uint32 interval, SDL_NewTimerCallback callback, void *param);

PHP_FUNCTION(sdl_addtimer)
{ /*
	// FIXME: doesn't work yet
	char *callback_name;
	php_sdl_timer_t *php_timer;
	zval ***args = NULL;

	if (ZEND_NUM_ARGS() < 2) {
		WRONG_PARAM_COUNT;
	}
	
	args = (zval ***)emalloc(ZEND_NUM_ARGS() * sizeof(zval **));
	if (zend_get_parameters_array_ex(ZEND_NUM_ARGS(), args) == FAILURE) {
		php_error(E_WARNING, "%s() unable to obtain function arguments",
				  get_active_function_name(TSRMLS_C));
		efree(args);
		RETURN_FALSE;
	}

	// First argument is the interval
	convert_to_long_ex(args[0]);

	// Second argument has to be a valid callback
	if (!zend_is_callable(*args[1], 0, &callback_name)) {
		php_error(E_WARNING, "%s() requires argument 2, '%s', to be a valid callback",
				  get_active_function_name(TSRMLS_C), callback_name);
		efree(callback_name);
		efree(args);
		RETURN_FALSE;
	}
	efree(callback_name);

 	php_timer = ecalloc(1, sizeof(php_sdl_timer_t));
	// We need the callers thread id for the callback to occur in the right thread
	php_timer->caller_thread_id = tsrm_thread_id();
	php_timer->callback_args = NULL;
	php_timer->num_callback_args = 0;

	// All parameters passed after the callback zval* are passed to the
	// callback itself.

	if ((php_timer->num_callback_args = ZEND_NUM_ARGS() - 2) > 0) {
		int i;
		if (NULL == (php_timer->callback_args = (zval **)emalloc(php_timer->num_callback_args * sizeof(zval *)))) {
			efree(php_timer);
			efree(args);
			RETURN_FALSE;
		}
		for (i = 0; i < php_timer->num_callback_args; i++) {
			zval_add_ref(args[2 + i]);
			php_timer->callback_args[0] = *args[2 + i];
		}
	}

	zval_add_ref(args[1]);
	php_timer->callback = *args[1];

	//php_timer->timerid = SDL_AddTimer((Uint32)Z_LVAL_PP(args[0]), php_sdl_timer_callback, (void*)php_timer);

	ZEND_REGISTER_RESOURCE(return_value, php_timer, le_timer);
	efree(args);
*/
}

/* }}} */

/* {{{ proto bool sdl_removetimer(resource id)

 */
// SDL_bool SDL_RemoveTimer(SDL_TimerID id);

PHP_FUNCTION(sdl_removetimer)
{/*
	// FIXME: doesn't work yet
	zval *timer_arg;
	php_sdl_timer_t *php_timer;

	if (zend_parse_parameters(ZEND_NUM_ARGS() TSRMLS_CC, "r", &timer_arg) == FAILURE)
		return;

	ZEND_FETCH_RESOURCE(php_timer, php_sdl_timer_t *, &timer_arg, -1, le_timer_name, le_timer);
	zend_list_delete(Z_RESVAL_P(timer_arg));
*/
}
/* }}} */

/*
 * Local variables:
 * tab-width: 4
 * c-basic-offset: 4
 * End:
 * vim600: noet sw=4 ts=4 fdm=marker
 * vim<600: noet sw=4 ts=4
 */
